current property
IsolateIdentity
get
current
The identity of the isolate this code is running in.
Implementation
static IsolateIdentity get current => _current;
The identity of the isolate this code is running in.
static IsolateIdentity get current => _current;