ip property
String?
get
ip
The IP address of the client that sent the request.
Uses TrustedProxy headers when configured on the router; otherwise the TCP remote address.
Implementation
String? get ip;
The IP address of the client that sent the request.
Uses TrustedProxy headers when configured on the router; otherwise the TCP remote address.
String? get ip;