Constructors
- AppConfig({required String host, required int port, String? prefix = _defaultPrefix, int workers = 1, int backlog = 0})
-
const
- AppConfig.defaultApp()
-
const
- AppConfig.secure({required String host, required int port, required SecurityContext securityContext, bool requestClientCertificate = false, String? prefix = _defaultPrefix, int workers = 1, int backlog = 0})
-
const
Properties
- backlog → int
-
Listen backlog passed to HttpServer.bind / HttpServer.bindSecure.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
final
- port → int
-
final
- prefix → String?
-
final
- requestClientCertificate → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securityContext → SecurityContext?
-
final
- workers → int
-
Number of isolates that accept connections on port.
final
Methods
-
configureDependencies(
covariant DI di) → Future< void> -
initializeDI(
) → DI -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onServerStarted(
HttpServer server) → void -
runStartup(
Future< HttpServer> start()) → Future<HttpServer> - Runs the async server startup sequence (bind, DI, routes, listen).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited